( cd usr/lib64 ; rm -rf libparted-1.8.so.8 )
( cd usr/lib64 ; ln -sf libparted-1.8.so.8.0.0 libparted-1.8.so.8 )
( cd usr/lib64 ; rm -rf libparted.so )
( cd usr/lib64 ; ln -sf libparted-1.8.so.8.0.0 libparted.so )
